==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/speech/translations/speech_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Texto a voz</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Número máximo de letras habladas</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Mensaje demasiado largo (hombre)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Mensaje demasiado largo (mujer)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voz</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Frecuencia base</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodía</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Sistema de sonido</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>ESD</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>DSP</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Dispositivo DSP</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Sintetizador Klatt (requiere DSP)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Programa de voz</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Prueba</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Leer un texto</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Formato de hombre</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Formato de mujer</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/speech/translations/speech_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Texto a voz</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Número máximo de letras habladas</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Mensaje demasiado largo (hombre)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Mensaje demasiado largo (mujer)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voz</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Frecuencia base</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodía</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Sistema de sonido</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>ESD</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>DSP</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Dispositivo DSP</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Sintetizador Klatt (requiere DSP)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Programa de voz</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Prueba</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Leer un texto</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Formato de hombre</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Formato de mujer</translation>
    </message>
</context>
</TS>
